Models
==============

`piel` provides a component model library to aid co-simulation. However, to extract a range of system performance parameters, simulations often tend to have to be done in different domains. This is why we need to have models that represent the same component, in different domains.

.. toctree::
    :caption: Contents:

    domains
    time_domain
    spice_integration

.. toctree::
    ../../autoapi/piel/models/index.rst
